@@ -1,24 +1,10 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 by Shawn Starr <shawn.starr@rogers.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007-2009 Shawn Starr <shawn.starr@rogers.com>
 
-#ifndef WEATHERENGINE_H
-#define WEATHERENGINE_H
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
+
+#pragma once
 
 #include <QHash>
 #include <QNetworkConfigurationManager>
@@ -119,5 +105,3 @@ private:
     QTimer m_reconnectTimer;
     QNetworkConfigurationManager m_networkConfigurationManager;
 };
-
-#endif
