@@ -1,28 +1,15 @@
 /*
- * main.h
- *
- * Copyright (c) 1999 Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
- * KDE Frameworks 5 port Copyright (C) 2013 Jonathan Riddell <jr@jriddell.org>
- * Copyright (c) 2018 Kai Uwe Broulik <kde@privat.broulik.de>
- * Copyright (C) 2019 Benjamin Port <benjamin.port@enioka.com>
- *
- * Requires the Qt widget libraries, available at no cost at
- * https://www.qt.io/
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    main.h
+
+    SPDX-FileCopyrightText: 1999 Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
+    SPDX-FileCopyrightText: 2018 Kai Uwe Broulik <kde@privat.broulik.de>
+    SPDX-FileCopyrightText: 2019 Benjamin Port <benjamin.port@enioka.com>
+
+    KDE Frameworks 5 port:
+    SPDX-FileCopyrightText: 2013 Jonathan Riddell <jr@jriddell.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #pragma once
 
@@ -72,6 +59,11 @@ public:
     bool downloadingFile() const;
 
     void load() override;
+    Q_INVOKABLE void reloadConfig()
+    {
+        ManagedConfigModule::load();
+    }
+
     void save() override;
     void defaults() override;
 
@@ -85,7 +77,7 @@ public:
     // QML doesn't understand QList<QPixmap>, hence wrapped in a QVariantList
     Q_INVOKABLE QVariantList previewIcons(const QString &themeName, int size, qreal dpr, int limit = -1);
 
-signals:
+Q_SIGNALS:
     void downloadingFileChanged();
 
     void showSuccessMessage(const QString &message);
